California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| Campaign Finance: PROP 1D - AB 127 (CHAPTER 35, 2006). NUNEZ. EDUCATION FACILITIES: KINDERGARTEN-UNIVERSITY PUBLIC EDUCATION FACILITIES BOND ACT OF 2006. View Information: General Information Late Independent Expenditures Affecting This Measure
How much money is being raised and spent to pass or defeat California propositions and ballot measures, and what are the sources of the money? Check here to follow the money trail.
Committees formed to support or oppose the ballot measure.
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
980478 | COALITION FOR ADEQUATE SCHOOL HOUSING ISSUES COMMITTEE/YES ON 1D | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1220380 | COMMUNITY COLLEGE FACILITY COALITION ISSUES COMMITTEE/YES ON 1D | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1224009 | CALIFORNIANS FOR HIGHER EDUCATION / YES ON 1D | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1245448 | CALIFORNIANS FOR ACCOUNTABILITY AND BETTER SCHOOLS, A COALITION OF TAXPAYERS, PARENTS, SENIORS, EDUCATORS, BUILDERS, LABOR AND BUSINESS | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1274538 | LEADERSHIP CALIFORNIA | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1288982 | CITIZENS FOR RESPONSIBLE ELECTIONS | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1288476 | YES ON PROP 1D, A COALITION OF PARENTS, BUSINESS AND EDUCATORS FOR BETTER SCHOOLS | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1289848 | COMMITTEE FOR CALIFORNIA'S FUTURE, YES ON PROPS 1A, 1B, 1C, 1D, 1E, 84 AND NO ON 85 | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1292233 | BI-PARTISANS TO REBUILD CALIFORNIA | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1287490 | LET'S REBUILD CALIFORNIA, LABOR, BUSINESS & COMMUTERS - YES ON 1A, 1B, 1C, 1D & IE - MAJOR FUNDING BY REBUILDING CA - YES ON 1A, 1B, 1C, 1D & 1E (DON PERATA) AND CONSTRUCTION AND LABOR FOR 1A | SUPPORT